
.. image:: https://readthedocs.org/projects/aws_codecommit/badge/?version=latest
    :target: https://aws_codecommit.readthedocs.io/index.html
    :alt: Documentation Status

.. image:: https://github.com/MacHu-GWU/aws_codecommit-project/workflows/CI/badge.svg
    :target: https://github.com/MacHu-GWU/aws_codecommit-project/actions?query=workflow:CI

.. image:: https://codecov.io/gh/MacHu-GWU/aws_codecommit-project/branch/master/graph/badge.svg
    :target: https://codecov.io/gh/MacHu-GWU/aws_codecommit-project

.. image:: https://img.shields.io/pypi/v/aws_codecommit.svg
    :target: https://pypi.python.org/pypi/aws_codecommit

.. image:: https://img.shields.io/pypi/l/aws_codecommit.svg
    :target: https://pypi.python.org/pypi/aws_codecommit

.. image:: https://img.shields.io/pypi/pyversions/aws_codecommit.svg
    :target: https://pypi.python.org/pypi/aws_codecommit

.. image:: https://img.shields.io/badge/STAR_Me_on_GitHub!--None.svg?style=social
    :target: https://github.com/MacHu-GWU/aws_codecommit-project

------


.. image:: https://img.shields.io/badge/Link-Document-blue.svg
    :target: https://aws_codecommit.readthedocs.io/index.html

.. image:: https://img.shields.io/badge/Link-API-blue.svg
    :target: https://aws_codecommit.readthedocs.io/py-modindex.html

.. image:: https://img.shields.io/badge/Link-Source_Code-blue.svg
    :target: https://aws_codecommit.readthedocs.io/py-modindex.html

.. image:: https://img.shields.io/badge/Link-Install-blue.svg
    :target: `install`_

.. image:: https://img.shields.io/badge/Link-GitHub-blue.svg
    :target: https://github.com/MacHu-GWU/aws_codecommit-project

.. image:: https://img.shields.io/badge/Link-Submit_Issue-blue.svg
    :target: https://github.com/MacHu-GWU/aws_codecommit-project/issues

.. image:: https://img.shields.io/badge/Link-Request_Feature-blue.svg
    :target: https://github.com/MacHu-GWU/aws_codecommit-project/issues

.. image:: https://img.shields.io/badge/Link-Download-blue.svg
    :target: https://pypi.org/pypi/aws_codecommit#files


Welcome to ``aws_codecommit`` Documentation
==============================================================================

``aws_codecommit`` aim to extract more potential from AWS CodeCommit.

Features:

- Git API for Human: let machine to commit code for you.
- Git Event hook automation: make AWS CodeCommit works with CI systems.


.. _install:

Install
------------------------------------------------------------------------------

``aws_codecommit`` is released on PyPI, so all you need is:

.. code-block:: console

    $ pip install aws_codecommit

To upgrade to latest version:

.. code-block:: console

    $ pip install --upgrade aws_codecommit